@@ -1,6 +1,7 @@
 use strict;
 package CPAN::Reporter;
-our $VERSION = '1.2011'; # VERSION
+
+our $VERSION = '1.2015';
 
 use Config;
 use Capture::Tiny qw/ capture tee_merged /;
@@ -522,6 +523,39 @@ TRANSPORT_REQUIRED
     return;
 }
 
+sub _report_timeout {
+    my $result = shift;
+    if ($result->{exit_value} == 9) {
+        my $config_obj = CPAN::Reporter::Config::_open_config_file();
+        my $config;
+        $config = CPAN::Reporter::Config::_get_config_options( $config_obj )
+            if $config_obj;
+
+        if ($config->{'_store_problems_in_dir'}) {
+            my $distribution = $result->{dist}->base_id;
+            my $file = "e9.$distribution.${\(time)}.$$.log";
+            if (open my $to_log_fh, '>>', $config->{'_store_problems_in_dir'}.'/'.$file) {
+                print $to_log_fh $distribution,"\n";
+                print $to_log_fh "stage: ",$result->{phase},"\n";
+                print $to_log_fh $Config{archname},"\n";
+                print $to_log_fh _report_text( $result );
+            } else {
+                $CPAN::Frontend->mywarn( "CPAN::Reporter: writing ".
+                    $config->{'_store_problems_in_dir'}.'/'.$file. " failed\n");
+            }
+        }
+        if ($config->{'_problem_log'}) {
+            my $distribution = $result->{dist}->base_id;
+            if (open my $to_log_fh, '>>', $config->{'_problem_log'}) {
+                print $to_log_fh "$result->{phase} $distribution $Config{archname}\n";
+            } else {
+                $CPAN::Frontend->mywarn( "CPAN::Reporter: writing ".
+                    $config->{'_store_problems_in_dir'}. " failed\n");
+            }
+        }
+    }
+}
+
 #--------------------------------------------------------------------------#
 # _downgrade_known_causes
 # Downgrade failure/unknown grade if we can determine a cause
@@ -544,6 +578,8 @@ sub _downgrade_known_causes {
     # get prereqs
     _expand_result( $result );
 
+    _report_timeout( $result );
+
     # if process was halted with a signal, just set for discard and return
     if ( $result->{exit_value} & 127 ) {
         $result->{grade} = 'discard';
@@ -562,7 +598,8 @@ sub _downgrade_known_causes {
         $harness_error++;
         last;
       }
-      if( $line =~ /Perl .*? required.*?--this is only/ims ||
+      if( $line =~ /(?<!skipped: )Perl .*? required.*?--this is only/ims ||
+           #?<! - quick hack for https://github.com/cpan-testers/CPAN-Reporter/issues/23
         $line =~ /Perl version .*? or higher required\. We run/ims || #EU::MM
         $line =~ /ERROR: perl: Version .*? is installed, but we need version/ims ||
         $line =~ /ERROR: perl \(.*?\) is installed, but we need version/ims ||
@@ -1099,6 +1136,43 @@ HERE
 
 );
 
+sub _comment_text {
+
+    # We assemble the completed comment as a series of "parts" which
+    # will get joined together
+    my @comment_parts;
+
+    # All automated testing gets a preamble
+    if ($ENV{AUTOMATED_TESTING}) {
+        push @comment_parts,
+            "this report is from an automated smoke testing program\n"
+            . "and was not reviewed by a human for accuracy"
+    }
+
+    # If a comment file is provided, read it and add it to the comment
+    my $confdir = CPAN::Reporter::Config::_get_config_dir();
+    my $comment_file = File::Spec->catfile($confdir, 'comment.txt');
+    if ( -d $confdir && -f $comment_file && -r $comment_file ) {
+        open my $fh, '<:encoding(UTF-8)', $comment_file or die($!);
+        my $text;
+        do {
+            local $/ = undef; # No record (line) seperator on input
+            $text = <$fh> or die($!);
+        };
+        chomp($text);
+        push @comment_parts, $text;
+        close $fh;
+    }
+
+    # If we have an empty comment so far, add a default value
+    if (scalar(@comment_parts) == 0) {
+        push @comment_parts, 'none provided';
+    }
+
+    # Join the parts seperated by a blank line
+    return join "\n\n", @comment_parts;
+}
+
 sub _report_text {
     my $data = shift;
     my $test_log = join(q{},@{$data->{output}});
@@ -1107,10 +1181,8 @@ sub _report_text {
         my $max_k = int(MAX_OUTPUT_LENGTH/1000) . "K";
         $test_log .= "\n[Output truncated after $max_k]\n\n";
     }
-    # Flag automated report
-    my $default_comment = $ENV{AUTOMATED_TESTING}
-        ? "this report is from an automated smoke testing program\nand was not reviewed by a human for accuracy"
-        : "none provided" ;
+
+    my $comment_body = _comment_text();
 
     # generate report
     my $output = << "ENDREPORT";
@@ -1133,7 +1205,7 @@ TESTER COMMENTS
 
 Additional comments from tester:
 
-$default_comment
+$comment_body
 
 ------------------------------
 PROGRAM OUTPUT
@@ -1505,7 +1577,7 @@ CPAN::Reporter - Adds CPAN Testers reporting to CPAN.pm
 
 =head1 VERSION
 
-version 1.2011
+version 1.2015
 
 =head1 SYNOPSIS
 
@@ -1600,6 +1672,28 @@ should copy it into the C<<< .cpanreporter >>> directory instead of creating
 a new one.  Profile files may be located outside the C<<< .cpanreporter >>>
 directory by following instructions in L<CPAN::Reporter::Config>.
 
+=head3 Default Test Comments
+
+This module puts default text into the "TESTER COMMENTS" section, typically,
+"none provided" if doing interactive testing, or, if doing smoke testing that
+sets CE<lt>$ENV{AUTOMATED_TESTING}E<gt> to a true value, "this report is from an
+automated smoke testing program and was not reviewed by a human for
+accuracy."  If CE<lt>CPAN::ReporterE<gt> is configured to allow editing of the
+report, this can be edited during submission.
+
+If you wish to override the default comment, you can create a file named
+CE<lt>comment.txtE<gt> in the configuration directory (typically C<<< .cpanreporter >>>
+under the user's home directory), with the default comment you would
+like to appear.
+
+Note that if your test is an automated smoke
+test (CE<lt>$ENV{AUTOMATED_TESTING}E<gt> is set to a true value), the smoke
+test notice ("this report is from an automated smoke testing program and
+was not reviewed by a human for accuracy") is included along with a blank
+line before your CE<lt>comment.txtE<gt>, so that it is always possible to
+distinguish automated tests from non-automated tests that use this
+module.
+
 =head2 Using CPAN::Reporter
 
 Once CPAN::Reporter is enabled and configured, test or install modules with
@@ -1667,6 +1761,9 @@ prior to sending it.
 
 =head1 BUGS
 
+Using command_timeout on Linux may cause problems. See
+L<https://rt.cpan.org/Ticket/Display.html?id=62310>
+
 Please report any bugs or feature using the CPAN Request Tracker.
 Bugs can be submitted through the web interface at
 L<http://rt.cpan.org/Dist/Display.html?Queue=CPAN-Reporter>
@@ -1733,6 +1830,8 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Alexandr Ciornii Breno G. de Oliveira Christian Walde Ed J Joel Maslak Kent Fredric Matthew Musgrove Patrice Clement Scott Wiersdorf Slaven Rezic
+
 =over 4
 
 =item *
@@ -1749,12 +1848,32 @@ Christian Walde <walde.christian@googlemail.com>
 
 =item *
 
+Ed J <mohawk2@users.noreply.github.com>
+
+=item *
+
+Joel Maslak <jmaslak@antelope.net>
+
+=item *
+
 Kent Fredric <kentfredric@gmail.com>
 
 =item *
 
 Matthew Musgrove <mr.muskrat@gmail.com>
 
+=item *
+
+Patrice Clement <monsieurp@gentoo.org>
+
+=item *
+
+Scott Wiersdorf <scott@perlcode.org>
+
+=item *
+
+Slaven Rezic <slaven@rezic.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
