@@ -1,6 +1,7 @@
 use strict;
 package CPAN::Reporter::Config;
-our $VERSION = '1.2011'; # VERSION
+
+our $VERSION = '1.2015';
 
 use Config::Tiny 2.08 ();
 use File::Glob ();
@@ -295,6 +296,12 @@ HERE
     retry_submission => {
         default => undef,
     },
+    '_store_problems_in_dir' => { #experimental
+        default => undef,
+    },
+    '_problem_log' => { #experimental
+        default => undef,
+    },
 );
 
 sub _config_spec { return %option_specs }
@@ -664,7 +671,7 @@ CPAN::Reporter::Config - Config file options for CPAN::Reporter
 
 =head1 VERSION
 
-version 1.2011
+version 1.2015
 
 =head1 SYNOPSIS
 
@@ -852,7 +859,7 @@ C<<< inactivity_timeout >>> is not set, then any commands executed by CPAN::Repo
 will be halted after this many seconds; useful for unattended smoke testing
 to stop after some amount of time; generally, this should be large --
 900 seconds or more -- as some distributions' tests take quite a long time to
-run.  On MSWin32, L<Win32::Job> is a needed and trying to kill a processes may
+run.  On MSWin32, L<Win32::Job> is a needed and trying to kill a process may
 actually deadlock in some situations -- so use at your own risk.
 
 =item *
