@@ -1,6 +1,7 @@
 use strict;
 package CPAN::Reporter::PrereqCheck;
-our $VERSION = '1.2011'; # VERSION
+
+our $VERSION = '1.2015';
 
 use ExtUtils::MakeMaker 6.36;
 use File::Spec;
@@ -11,11 +12,16 @@ _run() if ! caller();
 sub _run {
     my %saw_mod;
     # read module and prereq string from STDIN
+    # do this as early as possible: https://github.com/cpan-testers/CPAN-Reporter/issues/20
+    my @modules;
+    while ( <> ) {
+        push @modules, $_;
+    }
     local *DEVNULL;
     open DEVNULL, ">" . File::Spec->devnull; ## no critic
     # ensure actually installed, not ./inc/... or ./t/..., etc.
     local @INC = grep { $_ ne '.' } @INC;
-    while ( <> ) {
+    for (@modules) {
         m/^(\S+)\s+([^\n]*)/;
         my ($mod, $need) = ($1, $2);
         die "Couldn't read module for '$_'" unless $mod;
@@ -128,25 +134,37 @@ sub _try_load {
     qw/mylib/,
 
     #do not return true value
-    qw/perlsecret/,
+    qw/perlsecret Alt::Crypt::RSA::BigInt/,
   );
 
   my %loading_conflicts = (
     'signatures' => ['Catalyst'],
     'Dancer::Plugin::FlashMessage' => ['Dancer::Plugin::FlashNote'],
+    'Dancer::Plugin::FlashNote' => ['Dancer::Plugin::FlashMessage'],
     'Dancer::Plugin::Mongoose' => ['Dancer::Plugin::DBIC'],
     'Dancer::Plugin::DBIC' => ['Dancer::Plugin::Mongoose'],
+    'Test::Mock::LWP::UserAgent' => ['HTTP::Response'],
+    'Test::SharedFork' => ['threads'], #dies if $INC{'threads.pm'}
+    'Test::TCP' => ['threads'], #loads Test::SharedFork
+    'Test::Fake::HTTPD' => ['threads'], #loads Test::SharedFork
+    #Note: Test::Perl::Critic and other modules load threads, so reordering will not help
   ); #modules that conflict with each other
   
   my %load_before = (
     'Tk::Font' => 'Tk',
     'Tk::Widget' => 'Tk',
     'Tk::Label' => 'Tk',
+    'Tk::Menubutton' => 'Tk',
+    'Tk::Entry' => 'Tk',
     'Class::MOP::Class' => 'Class::MOP',
     'Moose::Meta::TypeConstraint::Role' => 'Moose',
     'Moose::Meta::TypeConstraint::Union' => 'Moose',
     'Moose::Meta::Attribute::Native' => 'Class::MOP',
+    'Moose::Meta::Role::Attribute' => 'Class::MOP',
     'Test::More::Hooks' => 'Test::More',
+    'Net::HTTP::Spore::Middleware::DefaultParams' => 'Net::HTTP::Spore::Meta::Method',
+    'Log::Log4perl::Filter' => 'Log::Log4perl',
+    'RDF::DOAP::Project' => 'RDF::Trine', #or other modules that use RDF::Trine will fail
   );
 
   # M::I < 0.95 dies in require, so we can't check if it loads
@@ -204,7 +222,7 @@ CPAN::Reporter::PrereqCheck - Modulino for prerequisite tests
 
 =head1 VERSION
 
-version 1.2011
+version 1.2015
 
 =head1 SYNOPSIS
 
